@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2003, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -32,8 +32,7 @@ import java.security.interfaces.*;
 import java.security.spec.*;
 
 import sun.security.action.GetPropertyAction;
-import sun.security.x509.AlgorithmId;
-import static sun.security.rsa.RSAUtil.KeyType;
+import sun.security.rsa.RSAUtil.KeyType;
 
 /**
  * KeyFactory for RSA keys, e.g. "RSA", "RSASSA-PSS".
@@ -44,13 +43,15 @@ import static sun.security.rsa.RSAUtil.KeyType;
  * between the following:
  *
  * For public keys:
- *  . PublicKey with an X.509 encoding
+ *  . RSA PublicKey with an X.509 encoding
+ *  . RSA PublicKey with an PKCS#1 encoding
  *  . RSAPublicKey
  *  . RSAPublicKeySpec
  *  . X509EncodedKeySpec
  *
  * For private keys:
- *  . PrivateKey with a PKCS#8 encoding
+ *  . RSA PrivateKey with a PKCS#8 encoding
+ *  . RSA PrivateKey with a PKCS#1 encoding
  *  . RSAPrivateKey
  *  . RSAPrivateCrtKey
  *  . RSAPrivateKeySpec
@@ -96,8 +97,8 @@ public class RSAKeyFactory extends KeyFactorySpi {
         return new RSAKeyFactory(type);
     }
 
-    // Internal utility method for checking key algorithm
-    private static void checkKeyAlgo(Key key, String expectedAlg)
+    // pkg-private utility method for checking key algorithm
+    static void checkKeyAlgo(Key key, String expectedAlg)
             throws InvalidKeyException {
         String keyAlg = key.getAlgorithm();
         if (keyAlg == null || !(keyAlg.equalsIgnoreCase(expectedAlg))) {
@@ -211,7 +212,7 @@ public class RSAKeyFactory extends KeyFactorySpi {
             throw new InvalidKeyException("Key must not be null");
         }
         // ensure the key algorithm matches the current KeyFactory instance
-        checkKeyAlgo(key, type.keyAlgo());
+        checkKeyAlgo(key, type.keyAlgo);
 
         // no translation needed if the key is already our own impl
         if ((key instanceof RSAPrivateKeyImpl) ||
@@ -259,21 +260,17 @@ public class RSAKeyFactory extends KeyFactorySpi {
             RSAPublicKey rsaKey = (RSAPublicKey)key;
             try {
                 return new RSAPublicKeyImpl(
-                    RSAUtil.createAlgorithmId(type, rsaKey.getParams()),
+                    type, rsaKey.getParams(),
                     rsaKey.getModulus(),
                     rsaKey.getPublicExponent());
             } catch (ProviderException e) {
                 // catch providers that incorrectly implement RSAPublicKey
                 throw new InvalidKeyException("Invalid key", e);
             }
-        } else if ("X.509".equals(key.getFormat())) {
-            RSAPublicKey translated = new RSAPublicKeyImpl(key.getEncoded());
-            // ensure the key algorithm matches the current KeyFactory instance
-            checkKeyAlgo(translated, type.keyAlgo());
-            return translated;
         } else {
-            throw new InvalidKeyException("Public keys must be instance "
-                + "of RSAPublicKey or have X.509 encoding");
+            // create new key based on the format and encoding of current 'key'
+            return RSAPublicKeyImpl.newKey(type, key.getFormat(),
+                key.getEncoded());
         }
     }
 
@@ -284,7 +281,7 @@ public class RSAKeyFactory extends KeyFactorySpi {
             RSAPrivateCrtKey rsaKey = (RSAPrivateCrtKey)key;
             try {
                 return new RSAPrivateCrtKeyImpl(
-                    RSAUtil.createAlgorithmId(type, rsaKey.getParams()),
+                    type, rsaKey.getParams(),
                     rsaKey.getModulus(),
                     rsaKey.getPublicExponent(),
                     rsaKey.getPrivateExponent(),
@@ -302,7 +299,7 @@ public class RSAKeyFactory extends KeyFactorySpi {
             RSAPrivateKey rsaKey = (RSAPrivateKey)key;
             try {
                 return new RSAPrivateKeyImpl(
-                    RSAUtil.createAlgorithmId(type, rsaKey.getParams()),
+                    type, rsaKey.getParams(),
                     rsaKey.getModulus(),
                     rsaKey.getPrivateExponent()
                 );
@@ -310,15 +307,9 @@ public class RSAKeyFactory extends KeyFactorySpi {
                 // catch providers that incorrectly implement RSAPrivateKey
                 throw new InvalidKeyException("Invalid key", e);
             }
-        } else if ("PKCS#8".equals(key.getFormat())) {
-            RSAPrivateKey translated =
-                RSAPrivateCrtKeyImpl.newKey(key.getEncoded());
-            // ensure the key algorithm matches the current KeyFactory instance
-            checkKeyAlgo(translated, type.keyAlgo());
-            return translated;
         } else {
-            throw new InvalidKeyException("Private keys must be instance "
-                + "of RSAPrivate(Crt)Key or have PKCS#8 encoding");
+            return RSAPrivateCrtKeyImpl.newKey(type, key.getFormat(),
+                    key.getEncoded());
         }
     }
 
@@ -326,16 +317,13 @@ public class RSAKeyFactory extends KeyFactorySpi {
     private PublicKey generatePublic(KeySpec keySpec)
             throws GeneralSecurityException {
         if (keySpec instanceof X509EncodedKeySpec) {
-            X509EncodedKeySpec x509Spec = (X509EncodedKeySpec)keySpec;
-            RSAPublicKey generated = new RSAPublicKeyImpl(x509Spec.getEncoded());
-            // ensure the key algorithm matches the current KeyFactory instance
-            checkKeyAlgo(generated, type.keyAlgo());
-            return generated;
+            return RSAPublicKeyImpl.newKey(type, "X.509",
+                    ((X509EncodedKeySpec)keySpec).getEncoded());
         } else if (keySpec instanceof RSAPublicKeySpec) {
             RSAPublicKeySpec rsaSpec = (RSAPublicKeySpec)keySpec;
             try {
                 return new RSAPublicKeyImpl(
-                    RSAUtil.createAlgorithmId(type, rsaSpec.getParams()),
+                    type, rsaSpec.getParams(),
                     rsaSpec.getModulus(),
                     rsaSpec.getPublicExponent()
                 );
@@ -352,16 +340,13 @@ public class RSAKeyFactory extends KeyFactorySpi {
     private PrivateKey generatePrivate(KeySpec keySpec)
             throws GeneralSecurityException {
         if (keySpec instanceof PKCS8EncodedKeySpec) {
-            PKCS8EncodedKeySpec pkcsSpec = (PKCS8EncodedKeySpec)keySpec;
-            RSAPrivateKey generated = RSAPrivateCrtKeyImpl.newKey(pkcsSpec.getEncoded());
-            // ensure the key algorithm matches the current KeyFactory instance
-            checkKeyAlgo(generated, type.keyAlgo());
-            return generated;
+            return RSAPrivateCrtKeyImpl.newKey(type, "PKCS#8",
+                    ((PKCS8EncodedKeySpec)keySpec).getEncoded());
         } else if (keySpec instanceof RSAPrivateCrtKeySpec) {
             RSAPrivateCrtKeySpec rsaSpec = (RSAPrivateCrtKeySpec)keySpec;
             try {
                 return new RSAPrivateCrtKeyImpl(
-                    RSAUtil.createAlgorithmId(type, rsaSpec.getParams()),
+                    type, rsaSpec.getParams(),
                     rsaSpec.getModulus(),
                     rsaSpec.getPublicExponent(),
                     rsaSpec.getPrivateExponent(),
@@ -378,7 +363,7 @@ public class RSAKeyFactory extends KeyFactorySpi {
             RSAPrivateKeySpec rsaSpec = (RSAPrivateKeySpec)keySpec;
             try {
                 return new RSAPrivateKeyImpl(
-                    RSAUtil.createAlgorithmId(type, rsaSpec.getParams()),
+                    type, rsaSpec.getParams(),
                     rsaSpec.getModulus(),
                     rsaSpec.getPrivateExponent()
                 );
@@ -396,7 +381,8 @@ public class RSAKeyFactory extends KeyFactorySpi {
         try {
             // convert key to one of our keys
             // this also verifies that the key is a valid RSA key and ensures
-            // that the encoding is X.509/PKCS#8 for public/private keys
+            // that the encoding is X.509/PKCS#8 or PKCS#1 for public/private
+            // keys
             key = engineTranslateKey(key);
         } catch (InvalidKeyException e) {
             throw new InvalidKeySpecException(e);
