@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -726,6 +726,14 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] ETC_UTC = new String[] {
+               "\u00c0m Uile-choitcheann Co-\u00f2rdanaichte",
+               "UTC",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Mauritius = new String[] {
                "Bun-\u00e0m nan Eileanan Mhoiriseas",
                "",
@@ -1282,16 +1290,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
-            { "UTC",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "UTC", ETC_UTC },
             { "Asia/Aden", Arabian },
             { "timezone.excity.America/Phoenix", "Phoenix" },
             { "timezone.excity.America/Antigua", "Aint\u00ecoga" },
@@ -1317,6 +1316,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             },
             { "timezone.excity.Antarctica/Vostok", "Vostok" },
             { "America/Panama", America_Eastern },
+            { "JST", Japan },
             { "timezone.excity.Pacific/Fiji", "F\u00ecdi" },
             { "timezone.excity.Europe/Gibraltar", "Diobraltar" },
             { "Europe/Jersey", GMT },
@@ -1336,6 +1336,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Tallinn", "Tallinn" },
             { "Asia/Phnom_Penh", Indochina },
             { "Africa/Kigali", Africa_Central },
+            { "BET", Brasilia },
             { "timezone.excity.Pacific/Guam", "Guam" },
             { "timezone.excity.Europe/Vaduz", "Vaduz" },
             { "America/Argentina/Salta", Argentina },
@@ -1476,6 +1477,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.America/Thule", "Qaanaaq" },
             { "timezone.excity.America/Grand_Turk", "An Turc Mh\u00f2r" },
             { "America/Yakutat", Alaska },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "Europe/Vienna", Europe_Central },
             { "timezone.excity.America/Winnipeg", "Winnipeg" },
             { "timezone.excity.Antarctica/Macquarie", "Eilean MhicGuaire" },
@@ -1523,6 +1525,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Pacific/Truk", Truk },
             { "timezone.excity.Africa/Conakry", "Conakry" },
             { "timezone.excity.Asia/Jakarta", "Jakarta" },
+            { "SST", Solomon },
             { "America/Jamaica", America_Eastern },
             { "Asia/Bishkek", Kyrgystan },
             { "Atlantic/Stanley", Falkland },
@@ -1544,6 +1547,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Mahe", "Mah\u00e9" },
             { "Europe/San_Marino", Europe_Central },
             { "America/Indiana/Tell_City", America_Central },
+            { "BST", Bangladesh },
             { "timezone.excity.Europe/Isle_of_Man", "Eilean Mhanainn" },
             { "Pacific/Saipan", Chamorro },
             { "timezone.excity.America/Curacao", "Cura\u00e7ao" },
@@ -1552,6 +1556,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Antarctica/Rothera", Rothera },
             { "timezone.excity.America/Guyana", "Guidhe\u00e0na" },
             { "Asia/Damascus", Europe_Eastern },
+            { "MIT", Apia },
             { "America/Argentina/San_Luis", Argentina_Western },
             { "timezone.excity.Europe/Paris", "Paras" },
             { "timezone.excity.Europe/Zagreb", "Zagreb" },
@@ -1569,16 +1574,6 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Chita", "Chita" },
             { "America/Indiana/Marengo", America_Eastern },
             { "timezone.excity.America/Rankin_Inlet", "Kangiqliniq" },
-            { "America/Punta_Arenas",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.America/Santarem", "Santar\u00e9m" },
             { "timezone.excity.Asia/Tomsk", "Tomsk" },
             { "timezone.excity.Europe/Helsinki", "Helsinki" },
@@ -1597,7 +1592,6 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Douala", "Douala" },
             { "Europe/Oslo", Europe_Central },
             { "timezone.excity.Africa/Mogadishu", "Mogadishu" },
-            { "timezone.excity.America/Bahia_Banderas", "Bah\u00eda de Banderas" },
             { "timezone.excity.Asia/Jayapura", "Jayapura" },
             { "America/Menominee", America_Central },
             { "timezone.excity.Pacific/Guadalcanal", "Guadalcanal" },
@@ -1663,17 +1657,8 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Europe/Tallinn", Europe_Eastern },
             { "Africa/Johannesburg", Africa_Southern },
             { "timezone.excity.Pacific/Fakaofo", "Fakaofo" },
+            { "EAT", Africa_Eastern },
             { "Africa/Bangui", Africa_Western },
-            { "Europe/Astrakhan",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Juba", Africa_Eastern },
             { "America/Campo_Grande", Amazon },
             { "America/Belem", Brasilia },
@@ -1694,6 +1679,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Cuiab\u00e1" },
             { "Pacific/Noumea", New_Caledonia },
+            { "ECT", Europe_Central },
             { "timezone.excity.Atlantic/Azores", "Ponta Delgada" },
             { "timezone.excity.Australia/Melbourne", "Melbourne" },
             { "America/Montreal", America_Eastern },
@@ -1721,6 +1707,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.America/Regina", "Regina" },
             { "SystemV/YST9YDT", Alaska },
             { "America/Merida", America_Central },
+            { "CAT", Africa_Central },
             { "America/St_Kitts", Atlantic },
             { "timezone.excity.America/Thunder_Bay", "Thunder Bay" },
             { "America/Fort_Nelson", America_Mountain },
@@ -1730,7 +1717,6 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.America/Louisville", "Louisville" },
-            { "timezone.excity.America/Cancun", "Canc\u00fan" },
             { "timezone.excity.Australia/Broken_Hill", "Broken Hill" },
             { "timezone.excity.Europe/Kaliningrad", "Kaliningrad" },
             { "America/North_Dakota/New_Salem", America_Central },
@@ -1744,16 +1730,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Europe/Vatican", Europe_Central },
             { "timezone.excity.America/Asuncion", "Asunci\u00f3n" },
             { "Asia/Amman", Europe_Eastern },
-            { "Etc/UTC",
-                new String[] {
-                    "\u00c0m Uile-choitcheann Co-\u00f2rdanaichte",
-                    "UTC",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "Etc/UTC", ETC_UTC },
             { "timezone.excity.Europe/Chisinau", "Chi\u0219in\u0103u" },
             { "timezone.excity.America/Moncton", "Moncton" },
             { "Asia/Singapore", Singapore },
@@ -1807,6 +1784,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Europe/Isle_of_Man", GMT },
             { "America/Araguaina", Brasilia },
             { "timezone.excity.Pacific/Easter", "Rapa Nui" },
+            { "ACT", Australia_Central },
             { "Asia/Novosibirsk", Novosibirsk },
             { "Africa/Tunis", Europe_Central },
             { "Pacific/Fakaofo", Tokelau },
@@ -1833,6 +1811,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Kirov", "Kirov" },
             { "timezone.excity.America/Creston", "Creston" },
             { "timezone.excity.Africa/Cairo", "Cairo" },
+            { "AET", Australia_Eastern },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "timezone.excity.Europe/Warsaw", "Warsaw" },
             { "Europe/Skopje", Europe_Central },
@@ -1842,16 +1821,6 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Africa/Algiers", Europe_Central },
             { "Europe/Mariehamn", Europe_Eastern },
             { "America/Anguilla", Atlantic },
-            { "Europe/Saratov",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Europe/Gibraltar", Europe_Central },
             { "Africa/Conakry", GMT },
             { "America/Havana", Cuba },
@@ -1888,16 +1857,6 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/Port_of_Spain", Atlantic },
             { "Asia/Beirut", Europe_Eastern },
             { "timezone.excity.Asia/Baghdad", "Baghd\u0101d" },
-            { "Pacific/Bougainville",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Sao_Tome", Africa_Western },
             { "Indian/Chagos", Indian_Ocean },
             { "timezone.excity.America/Metlakatla", "Metlakatla" },
@@ -1910,6 +1869,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.America/Panama", "Panama" },
             { "timezone.excity.Europe/Simferopol", "Simferopol" },
             { "timezone.excity.Indian/Kerguelen", "Kergelenn" },
+            { "CNT", Newfoundland },
             { "timezone.excity.Europe/Volgograd", "Volgograd" },
             { "timezone.excity.Europe/Monaco", "Monaco" },
             { "Asia/Tashkent", Uzbekistan },
@@ -1931,6 +1891,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.America/Managua", "Managua" },
             { "America/Kralendijk", Atlantic },
             { "Indian/Christmas", Christmas },
+            { "NET", Armenia },
             { "America/Inuvik", America_Mountain },
             { "America/Iqaluit", America_Eastern },
             { "Pacific/Funafuti", Tuvalu },
@@ -1974,11 +1935,13 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Asia/Chongqing", China },
             { "America/Indiana/Knox", America_Central },
             { "timezone.excity.Asia/Saigon", "Cathair Ho Chi Minh" },
+            { "PLT", Pakistan },
             { "America/North_Dakota/Beulah", America_Central },
             { "timezone.excity.Asia/Makassar", "Makassar" },
             { "Pacific/Apia", Apia },
             { "Pacific/Niue", Niue },
             { "timezone.excity.Asia/Yekaterinburg", "Yekaterinburg" },
+            { "CST", America_Central },
             { "timezone.excity.Europe/Sofia", "Sofiya" },
             { "MST7MDT", America_Mountain },
             { "America/Monterrey", America_Central },
@@ -1990,6 +1953,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.America/Denver", "Denver" },
             { "Indian/Mahe", Seychelles },
             { "Asia/Aqtobe", Kazakhstan_Western },
+            { "CTT", China },
             { "timezone.excity.Asia/Gaza", "G\u00e0sa" },
             { "timezone.excity.Africa/Ceuta", "Ceuta" },
             { "Africa/Libreville", Africa_Western },
@@ -1999,6 +1963,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.Antarctica/Troll", "Troll" },
             { "America/Aruba", Atlantic },
             { "America/North_Dakota/Center", America_Central },
+            { "PNT", America_Mountain },
             { "timezone.excity.Asia/Hong_Kong", "Hong Kong" },
             { "timezone.excity.America/Port-au-Prince", "Port-au-Prince" },
             { "America/Tijuana", America_Pacific },
@@ -2007,8 +1972,8 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Kwajalein", "Kwajalein" },
             { "SystemV/YST9", Gambier },
             { "Africa/Douala", Africa_Western },
-            { "America/Chihuahua", Mexico_Pacific },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Chihuahua", America_Central },
+            { "America/Ojinaga", America_Central },
             { "Asia/Hovd", Hovd },
             { "timezone.excity.Europe/Lisbon", "Lisbon" },
             { "timezone.excity.Pacific/Gambier", "Mangareva" },
@@ -2016,6 +1981,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/Santiago", Chile },
             { "timezone.excity.Europe/Zaporozhye", "Zaporozhye" },
             { "Asia/Baku", Azerbaijan },
+            { "ART", Europe_Eastern },
             { "America/Argentina/Ushuaia", Argentina },
             { "Atlantic/Reykjavik", GMT },
             { "Africa/Brazzaville", Africa_Western },
@@ -2026,17 +1992,8 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Kampala", "Kampala" },
             { "timezone.excity.Pacific/Chatham", "Chatham" },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
-            { "Antarctica/Palmer",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Addis_Ababa", Africa_Eastern },
+            { "AST", Alaska },
             { "Europe/Uzhgorod", Europe_Eastern },
             { "timezone.excity.Asia/Colombo", "Colombo" },
             { "timezone.excity.Pacific/Port_Moresby", "Port Moresby" },
@@ -2054,6 +2011,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Atlantic/South_Georgia", South_Georgia },
             { "Europe/Lisbon", Europe_Western },
             { "Asia/Harbin", China },
+            { "PRT", Atlantic },
             { "Asia/Novokuznetsk", Krasnoyarsk },
             { "timezone.excity.America/Cordoba", "C\u00f3rdoba" },
             { "timezone.excity.America/Cambridge_Bay", "Cambridge Bay" },
@@ -2082,6 +2040,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Qatar", "Catar" },
             { "timezone.excity.Australia/Sydney", "Sidni" },
             { "timezone.excity.America/Sitka", "Sitka" },
+            { "PST", America_Pacific },
             { "SystemV/EST5", America_Eastern },
             { "timezone.excity.Antarctica/Davis", "Davis" },
             { "America/Santo_Domingo", Atlantic },
@@ -2134,6 +2093,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/Porto_Velho", Amazon },
             { "America/Scoresbysund", Greenland_Eastern },
             { "Asia/Kamchatka", Kamchatka },
+            { "NST", New_Zealand },
             { "timezone.excity.Asia/Samarkand", "Samarkand" },
             { "Africa/Khartoum", Africa_Central },
             { "timezone.excity.Asia/Singapore", "Singeap\u00f2r" },
@@ -2158,7 +2118,6 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.America/Whitehorse", "Whitehorse" },
             { "timezone.excity.Asia/Kuching", "Kuching" },
             { "timezone.excity.America/Halifax", "Halifax" },
-            { "timezone.excity.America/Merida", "M\u00e9rida" },
             { "America/Pangnirtung", America_Eastern },
             { "timezone.excity.Pacific/Palau", "Palabh" },
             { "Asia/Katmandu", Nepal },
@@ -2181,31 +2140,11 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Asia/Atyrau", Kazakhstan_Western },
             { "Australia/Darwin", Australia_Central },
             { "Asia/Kuala_Lumpur", Malaysia },
-            { "Asia/Famagusta",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Europe/Bratislava", Europe_Central },
             { "timezone.excity.Atlantic/Stanley", "Stanley" },
             { "Pacific/Tongatapu", Tonga },
             { "timezone.excity.Asia/Rangoon", "Rangun" },
             { "timezone.excity.Asia/Thimphu", "Thimphu" },
-            { "Europe/Ulyanovsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.Asia/Dubai", "Dubai" },
             { "Arctic/Longyearbyen", Europe_Central },
             { "timezone.excity.Asia/Kuala_Lumpur", "Kuala Lumpur" },
@@ -2213,16 +2152,6 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Indian/Kerguelen", French_Southern },
             { "timezone.excity.Africa/Ouagadougou", "Ouagadougou" },
             { "timezone.excity.Africa/Gaborone", "Gaborone" },
-            { "Asia/Srednekolymsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Asia/Anadyr", Anadyr },
             { "timezone.excity.Indian/Chagos", "Chagos" },
             { "timezone.excity.America/Iqaluit", "Iqaluit" },
