@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -1464,6 +1464,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.America/Thule", "Thule" },
             { "timezone.excity.America/Grand_Turk", "Grand Turk" },
             { "America/Yakutat", Alaska },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "Europe/Vienna", Europe_Central },
             { "timezone.excity.America/Winnipeg", "Winnipeg" },
             { "timezone.excity.Antarctica/Macquarie", "Macquarie" },
@@ -1704,7 +1705,6 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.America/Louisville", "Louisville" },
-            { "timezone.excity.America/Cancun", "Canc\u00fan" },
             { "timezone.excity.Australia/Broken_Hill", "Broken Hill" },
             { "timezone.excity.Europe/Kaliningrad", "Kalinyingr\u00e1d" },
             { "America/North_Dakota/New_Salem", America_Central },
@@ -1959,8 +1959,8 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Kwajalein", "Kwajalein-z\u00e1tony" },
             { "SystemV/YST9", Gambier },
             { "Africa/Douala", Africa_Western },
-            { "America/Chihuahua", Mexico_Pacific },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Chihuahua", America_Central },
+            { "America/Ojinaga", America_Central },
             { "Asia/Hovd", Hovd },
             { "timezone.excity.Europe/Lisbon", "Lisszabon" },
             { "timezone.excity.Pacific/Gambier", "Gambier-szigetek" },
@@ -2096,7 +2096,6 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.America/Whitehorse", "Whitehorse" },
             { "timezone.excity.Asia/Kuching", "Kucseng" },
             { "timezone.excity.America/Halifax", "Halifax" },
-            { "timezone.excity.America/Merida", "M\u00e9rida" },
             { "America/Pangnirtung", America_Eastern },
             { "timezone.excity.Pacific/Palau", "Palau" },
             { "Asia/Katmandu", Nepal },
