@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -1457,6 +1457,7 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.America/Thule", "Tule" },
             { "timezone.excity.America/Grand_Turk", "Grandtk\u0113rka" },
             { "America/Yakutat", Alaska },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "timezone.excity.America/Indiana/Petersburg", "P\u012btersb\u0113rga, Indi\u0101na" },
             { "Europe/Vienna", Europe_Central },
             { "timezone.excity.America/Winnipeg", "Vinipega" },
@@ -1964,8 +1965,8 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Kwajalein", "Kvad\u017ealeina" },
             { "SystemV/YST9", Gambier },
             { "Africa/Douala", Africa_Western },
-            { "America/Chihuahua", Mexico_Pacific },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Chihuahua", America_Central },
+            { "America/Ojinaga", America_Central },
             { "Asia/Hovd", Hovd },
             { "timezone.excity.Europe/Lisbon", "Lisabona" },
             { "timezone.excity.Pacific/Gambier", "Gambj\u0113 salas" },
