@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -70,6 +70,14 @@ import sun.util.resources.TimeZoneNamesBundle;
 public class TimeZoneNames_pt_MO extends TimeZoneNamesBundle {
     @Override
     protected final Object[][] getContents() {
+        final String[] EMPTY_ZONE = new String[] {
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Europe_Western = new String[] {
                "Hora padr\u00e3o da Europa Ocidental",
                "\u2205\u2205\u2205",
@@ -106,16 +114,7 @@ public class TimeZoneNames_pt_MO extends TimeZoneNamesBundle {
             { "Europe/Paris", Europe_Central },
             { "Africa/Casablanca", Europe_Western },
             { "Europe/Bucharest", Europe_Eastern },
-            { "UTC",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "UTC", EMPTY_ZONE },
             { "Europe/Ljubljana", Europe_Central },
             { "Asia/Nicosia", Europe_Eastern },
             { "Europe/Kaliningrad", Europe_Eastern },
@@ -128,16 +127,6 @@ public class TimeZoneNames_pt_MO extends TimeZoneNamesBundle {
             { "Europe/Chisinau", Europe_Eastern },
             { "Atlantic/Faeroe", Europe_Western },
             { "Europe/Stockholm", Europe_Central },
-            { "Asia/Famagusta",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Europe/Budapest", Europe_Central },
             { "Atlantic/Canary", Europe_Western },
             { "Europe/Bratislava", Europe_Central },
@@ -150,26 +139,6 @@ public class TimeZoneNames_pt_MO extends TimeZoneNamesBundle {
             { "Europe/Brussels", Europe_Central },
             { "Atlantic/Azores", Azores },
             { "Europe/Vienna", Europe_Central },
-            { "Pacific/Bougainville",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "Europe/Ulyanovsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Europe/Busingen", Europe_Central },
             { "Europe/Warsaw", Europe_Central },
             { "Europe/Tallinn", Europe_Eastern },
@@ -185,73 +154,25 @@ public class TimeZoneNames_pt_MO extends TimeZoneNamesBundle {
             { "Europe/Kiev", Europe_Eastern },
             { "Europe/Rome", Europe_Central },
             { "Asia/Hebron", Europe_Eastern },
+            { "ART", Europe_Eastern },
             { "Europe/Zaporozhye", Europe_Eastern },
-            { "Europe/Astrakhan",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Atlantic/Jan_Mayen", Europe_Central },
-            { "Asia/Srednekolymsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Ceuta", Europe_Central },
             { "Africa/Algiers", Europe_Central },
             { "Europe/Mariehamn", Europe_Eastern },
             { "Europe/Zurich", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
             { "Europe/Amsterdam", Europe_Central },
-            { "Europe/Saratov",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Atlantic/Madeira", Europe_Western },
             { "Europe/Vatican", Europe_Central },
-            { "Antarctica/Palmer",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Europe/Gibraltar", Europe_Central },
             { "Asia/Amman", Europe_Eastern },
             { "Europe/Madrid", Europe_Central },
             { "Europe/Uzhgorod", Europe_Eastern },
             { "Europe/Vaduz", Europe_Central },
             { "Europe/Sofia", Europe_Eastern },
-            { "America/Punta_Arenas",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Europe/Prague", Europe_Central },
+            { "ECT", Europe_Central },
             { "Africa/Tunis", Europe_Central },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Andorra", Europe_Central },
