@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -1458,6 +1458,7 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "Atlantic/Faeroe", Europe_Western },
             { "Asia/Qyzylorda", Kazakhstan_Eastern },
             { "America/Yakutat", Alaska },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "Antarctica/Casey", Casey },
             { "Europe/Copenhagen", Europe_Central },
             { "Atlantic/Azores", Azores },
@@ -1537,8 +1538,8 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "SystemV/YST9", Gambier },
             { "timezone.excity.America/Curacao", "\u0643\u06c7\u0631\u0627\u0633\u0648" },
             { "Africa/Douala", Africa_Western },
-            { "America/Chihuahua", Mexico_Pacific },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Chihuahua", America_Central },
+            { "America/Ojinaga", America_Central },
             { "Asia/Hovd", Hovd },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Damascus", Europe_Eastern },
